﻿using System.ComponentModel.Composition;
using Microsoft.Research.Rin.DataModel;
using MicrosoftResearch.Rin.RinPlayerContracts;

namespace MicrosoftResearch.Rin.Samples
{
    /// <summary>
    /// Factory to create experience streams. For each ES Provider Type Id, one factory is required 
    /// and be registered using MEF by [Export(typeof(IExperienceStreamFactory))] attribute.
    /// </summary>
    [Export(typeof(IExperienceStreamFactory))]
    public class ExperienceStreamFactory : BaseV1ExperienceStreamFactory
    {
        public override IExperienceStream CreateInstance(ExperienceStreamData esData, IOrchestrator orchestrator)
        {
            return new HelloWorldExperienceStream(orchestrator, esData);
        }

        /// <summary>
        /// A unique id for experience streams it generates. Make sure that the ProviderTypeId 
        /// follows this format to avoid naming collisions: [company name].[project name].[experience stream name] 
        /// </summary>
        public override string ProviderTypeId
        {
            get { return "MicrosoftResearch.Rin.Samples.HelloWorldES"; }
        }

    }
}
