﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Research.Rin.AuthoringContracts.Interfaces;
using System.ComponentModel.Composition;
using System.Windows.Media.Imaging;

namespace RinStudioSdk.Samples.ChessSampleAsset
{
    [Export(typeof(IAssetType))]
    public class ChessAsset : IAssetType
    {
        BitmapImage image;

        /// <summary>
        ///ContentType used by Rin Studio. This has to be unique user readable name.
        /// </summary>
        public string ContentType
        {
            get { return "ChessSample"; }
        }

        /// <summary>
        ///Implement this method if you have written extra copying of files in GenerateThumbnailAndTitle method.
        ///This is called during delete of Asset. Also this is valid only if the usage od this assets requires importing of files.
        /// </summary>
        /// <param name="sourceFile">Source file that was selected by end user to import as this asset type</param>
        /// <param name="destinationFolder">this is location of folder where the files are stored in RinStudio</param>
        public void DeleteRelatedFiles(Uri sourceFile, Uri destinationFolder)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        ///During import of files, this method will be called by tell the RinStudio to generate thumbnail, title and know the default duration of this media.
        ///This method can also be used to copy any dependent files to the destination location. But ensure to delete those additional files during DeleteRelatedFiles call.
        /// 
        /// if the usage of this Asset is without import and use them directly in Rin Studio [UsageMethod], then make sure that Thumbnail is still generated, as this will be used to show it to the user.
        ///The thumbnail can be a Pack Uri in case you want to show the same thumbnail, or if file based thumbnails are required then make sure that thumbnail is created in destination location 
        /// and return that path in Asset details Uri
        /// </summary>
        /// <param name="sourceFile">Source file that was selected by end user to import as this asset type</param>
        /// <param name="destinationFolder">this is location of folder where the files are stored in RinStudio</param>
        /// <param name="error">To return any exceptions or errors, use this out param</param>
        /// <returns>Return the asset details with required information</returns>
        public AssetDetails GenerateThumbnailAndTitle(Uri sourceFile, Uri destinationFolder, out string error)
        {
            error = null;
            return new AssetDetails(new Uri(@"pack://application:,,,/RinStudioSdk.Samples.ChessSampleAsset;component/Resources/icon.png"), "Chess Sample", TimeSpan.Zero);
        }

        /// <summary>
        ///During the import of the files, the extension for the files are displayed. Also based on this extension the asset type is chosen to import the file.
        /// Return the array of extensions {"*.pqr",*.abc} etc., supported to import the file.
        /// </summary>
        /// <returns>string array of the extensions </returns>
        public string[] GetSupportedFileExtensions()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// returns the image to be displayed as small icon for this asset type.
        /// </summary>
        public System.Windows.Media.Imaging.BitmapImage IconImage
        {
            get
            {
                if (this.image == null)
                {
                    this.image = new BitmapImage(new Uri(@"pack://application:,,,/RinStudioSdk.Samples.ChessSampleAsset;component/Resources/icon.png", UriKind.RelativeOrAbsolute));
                }
                return this.image;
            }
        }

        /// <summary>
        /// if your asset type supports local file imports then return if the extension is supported.
        /// </summary>
        /// <param name="extension">extension passed by the Rin Studio to check</param>
        /// <returns>return true if the extension is supported else return false</returns>
        public bool IsSupportedFileExtension(string extension)
        {
            return false;
        }

        /// <summary>
        /// Rin Studio also supports importing the Urls. And the asset type can be chosen to perform some tasks on it.
        /// Rin studio will pass the Urls and if the user is supported return true else return false.
        /// </summary>
        /// <param name="url">Url passed by Rin Studio</param>
        /// <param name="error">error parameter if there was any exception, or want to convey the exception to the user</param>
        /// <returns>return true if the url is valid, else return false</returns>
        public bool IsValidUrl(string url, out string error)
        {
            error = null;
            return false;
        }

        /// <summary>
        ///This is important. This should return the fully qualified class name in the Rin Player SDK that can handle the experience. 
        ///This is the class that implements IExperienceStream or IAuthorableExperienceStream
        /// </summary>
        public string ProviderName
        {
            get { return "MicrosoftResearch.Rin.Samples.ChessES"; }
        }

        /// <summary>
        ///Rin Studio lets user import files or use the default assets which do not require importing files.
        ///Based on the SupportedUsageMethod, Rin Studio will place the assets. 
        ///If your assets works only with importing files or Url then use SupportedUsageMethod.Import
        ///If your assets works without importing files and Url then use SupportedUsageMethod.Direct
        ///If your assets works with and without importing files and Url then use SupportedUsageMethod.ImportOrDirect
        /// </summary>
        public SupportedUsageMethod UsageMethod
        {
            get { return SupportedUsageMethod.Direct; }
        }

        /// <summary>
        /// This should generate the preview image for the content
        /// </summary>
        /// <param name="sourceFile">Path to the Source File to generate the Thumbnail</param>
        /// <param name="destinationFolder">Path to the destination Folder where the file should be created</param>
        /// <param name="error">This out parameter should contain all the error messages require to be diapled to the User</param> 
        public Uri GeneratePreview(Uri sourceFile, Uri destinationFolder, out string error)
        {
            error = null;
            return null;
        }
    }
}
