﻿#region Namespaces
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Research.Rin.AuthoringContracts.Interfaces;
using System.ComponentModel.Composition;
using System.Windows.Media.Imaging;

#endregion

namespace HelloWorldES
{
    /// <summary>
    /// Attribute required by MEF for loading the asset type.
    /// </summary>
    [Export(typeof(IAssetType))]
    public class HelloWorldAssetType : IAssetType
    {
        #region Members
        BitmapImage image;
        #endregion
        
        #region IAssetType members

        /// <summary>
        /// string representation of the content type supported by this asset
        /// </summary>
        string IAssetType.ContentType
        {
            get { return "HelloWorldES"; }
        }

        /// <summary>
        /// This will return the ICON Image
        /// </summary>
        BitmapImage IAssetType.IconImage
        {
            get
            {
                if (this.image == null)
                {
                    this.image = new BitmapImage(new Uri(@"pack://application:,,,/HelloWorldAsset;component/Resources/icon.png", UriKind.RelativeOrAbsolute));
                }
                return this.image;
            }
        }

        /// <summary>
        /// This method should help determine if the given extension is supported by the 
        /// Asset type
        /// </summary>
        /// <param name="extension">extension to be supported</param>
        /// <returns>status</returns>
        bool IAssetType.IsSupportedFileExtension(string extension)
        {
            //-- Return false since its a direct asset
            return false;
        }
        
        /// <summary>
        /// Experience stream Provider Name on the player side
        /// </summary>
        string IAssetType.ProviderName
        {
            get { return "MicrosoftResearch.Rin.Samples.HelloWorldES"; }
        }

        /// <summary>
        /// Defines the usage method of this Asset type
        /// </summary>
        SupportedUsageMethod IAssetType.UsageMethod
        {
            get { return SupportedUsageMethod.Direct; }
        }


        // <summary>
        /// This method will validate the URL entered by the user (when Importing an asset)
        /// and return the error message if return value is false in the error parameter
        /// </summary>
        /// <param name="url">Url to validate</param>
        /// <param name="error">error message to display</param>
        /// <returns>status if the URl is valid or invalid</returns>
        bool IAssetType.IsValidUrl(string url, out string error)
        {
            //-- Return false since its a direct asset
            error = null;
            return false;
        }


        /// <summary>
        /// This method will generate the Thumbnail and title for the supported assets
        /// </summary>
        /// <param name="sourceFile">Source path for the Asset</param>
        /// <param name="destinationFolder">Destination path for the Asset</param>
        /// <param name="error">The error message in case of any exception</param>
        /// <returns>AssetDetails with Thumbnail URl and the Title and default duration</returns>
        AssetDetails IAssetType.GenerateThumbnailAndTitle(Uri sourceFile, Uri destinationFolder, out string error)
        {
            error = null;
            return new AssetDetails(new Uri(@"pack://application:,,,/HelloWorldAsset;component/Resources/images.jpg"), "Hello World ES", TimeSpan.Zero);
        }

        /// <summary>
        /// This function should return the supported file extenstions
        /// </summary>
        /// <returns>string array of supported extenstions</returns>
        string[] IAssetType.GetSupportedFileExtensions()
        {
            //-- Implementation required only for imported assets.
            throw new NotImplementedException();
        }
                
        /// <summary>
        /// Deletes the files related to sourceFile if there were any.
        /// </summary>
        /// <param name="sourceFile">Main file that user imported</param>
        /// <param name="destinationFolder">location where related files were copied and should be deleted from</param>
        void IAssetType.DeleteRelatedFiles(Uri sourceFile, Uri destinationFolder)
        {
            throw new NotImplementedException();
        }

        #endregion
    }
}
